@@ -4,7 +4,7 @@ from _csv import CSVExporter
 from _sas import SASExporter
 from _r import RExporter
 from _json import JSONExporter
-from _html import HTMLExporter
+from _html import HTMLExporter      # noqa
 
 registry = loader.Registry(register_instance=False)
 
