@@ -25,7 +25,7 @@ class BaseExporter(object):
 
     def __repr__(self):
         return u'<{0}: {1}/{2}>'.format(self.__class__.__name__,
-            len(self.params), self.row_length)
+                                        len(self.params), self.row_length)
 
     def add_formatter(self, formatter, length=None, index=None):
         if isinstance(formatter, DataConcept):
@@ -35,7 +35,7 @@ class BaseExporter(object):
             length = len(formatter.keys)
         elif length is None:
             raise ValueError('A length must be supplied with the to '
-                'denote how much of the row will be formatted.')
+                             'denote how much of the row will be formatted.')
 
         params = (formatter, length)
         self.row_length += length
@@ -55,7 +55,8 @@ class BaseExporter(object):
     def _format_row(self, row, **kwargs):
         for formatter, length in self.params:
             values, row = row[:length], row[length:]
-            yield formatter(values, preferred_formats=self.preferred_formats, **kwargs)
+            yield formatter(values, preferred_formats=self.preferred_formats,
+                            **kwargs)
 
     def read(self, iterable, force_distinct=True, *args, **kwargs):
         """Takes an iterable that produces rows to be formatted.
